// name: Window Driver for jBOS
// author: Nathaniel van Diepen
// version: 1.0
// description: Window manipulation functions that are not included in jDesktop
;(function($){	
	$.extend({
		task:{
			// returns the index to the task pointed to by the id
			getIndex: function(id){
				var x = 0;
				while(x<$.task.tasks.length && $.task.tasks[x].id!=id){
					x++;
				}
				if(x!=$.task.tasks.length)
					return x;
				return false;
			},
			// diables a task
			stop: function(id){
				var x = $.task.getIndex(id);
				if(x<$.task.tasks.length){
					if($.task.tasks[x].running)
						clearTimeout($.task.tasks[x].pointer)
					$.task.tasks[x].onstop();
					$.task.tasks[x].active = false;
					$.task.tasks[x].running = false;
					return x;
				}else
					return false;
			},
			// enables a task
			start: function(id){
				var x = $.task.getIndex(id);
				if(x<$.task.tasks.length){
					$.task.tasks[x].active = true;
					$.task.tasks[x].onstart();
					return x;
				}else
					return false;
			},
			// an array containing all the task objects
			tasks: new Array(),
			// ends a task
			end: function(id){
				var x = $.task.getIndex(id);
				if($.task.tasks[x].running)
					$.task.stop(id);
				if(x || x==0){
					if($.task.tasks[x].running)
						clearTimeout($.task.tasks[x].pointer)
						$.task.tasks[x].onend();
						$.task.tasks.remove(x);
					return true;
				}else
				return false;
			},
			// creates a new task
			create: function(task){
				$.task.tasks[$.task.tasks.length] = task;
			},
			// run through and execute the tasks
			run: function(){
				var task = new String();
				for(var x=0;x<$.task.tasks.length;x++){
					if(!$.task.tasks[x].running && $.task.tasks[x].active){
						$.task.tasks[x].pointer = setInterval($.task.tasks[x].onexec,$.task.tasks[x].interrupt);
						$.task.tasks[x].running = true;
					}
				}
			},
			// tasker intterupt for turning off if necessary
			TASKER: setInterval(function(){$.task.run()},1000)
		}
	});
})(jQuery);
// Task Object define
function Task(app,name,id,interrupt,onstart,onexec,onstop,onend){
	if(!name)
		this.name = new String();
	else
		this.name = name;
	if(!id)
		this.id = new String();
	else
		this.id = id;
	if(!interrupt)
		this.interrupt = 0;
	else
		this.interrupt = interrupt;
	if(!onstart)
		this.onstart = function(){};
	else
		this.onstart = onstart;
	if(!onexec)
		this.onexec = function(){};
	else
		this.onexec = onexec;
	if(!onstop)
		this.onstop = function(){};
	else
		this.onstop = onstop;
	if(!onend)
		this.onend = function(){};
	else
		this.onend = onend;
	if(app)
		this.app = app;
	else
		this.app = new String();
	this.running = false;
	this.active = false;
	this.pointer = false;
	// shortcut for $.task.create(object)
	this.init = function(){
		$.task.tasks[$.task.tasks.length] = this;
	};
	// starts the task
	this.start = function(){
		$.task.start(this.id);
	};
	//stops the task
	this.stop = function(){
		$.task.stop(this.id);
	};
	//ends the task
	this.end = function(){
		$.task.end(this.id);
	};
}